.. _rad:

**************************
Roman Attribute Dictionary
**************************

The Roman Attribute Dictionary (RAD) is package which defines schemas for the Nancy Grace
Roman Space Telescope shared attributes for processing and archive.

.. note::
  These schemas are schemas for the :ref:`ASDF file <asdf-standard:asdf-standard>` file format, which
  are used by ASDF to serialize and deserialze data for the Nancy Grace Roman Space Telescope.

Included Resources
==================

The following are listings of all the schemas provided by this package for ASDF.

.. note::
  Typically, schemas are used in ASDF via their tag, which can be found in the manifest.

.. toctree::
  :maxdepth: 1

  schemas.rst
  reference_files.rst
  manifests.rst

Developer Resources
===================

.. toctree::
  :maxdepth: 1

  contributing.rst
  changes.rst

Index
=====

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
